# Intro

Hello,

This is a package with a bunch of simple functions which I use often on Windows/Linux and might also be helpful for you.

I'm uploading this mainly for personal usage and also as a packaging tutorial.
